==> storebounty_account-0.0.1.tar.gz: lib/favourites/favourites.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:storebounty_account/common/tabbar.dart';
import 'package:storebounty_account/model/singleproductmodel.dart' as singleProductModel;
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/widget/emptyfavs.dart';
import 'package:storebounty_account/widget/favcards/fullcard.dart';
import 'package:storebounty_account/widget/favcards/gridcard.dart';
import 'package:storebounty_init/storebountyinit.dart';

class UserFavourites extends StatefulWidget {
  final String? cardStyle;
  const UserFavourites({super.key, this.cardStyle = "grid"});

  @override
  State<UserFavourites> createState() => _UserFavouritesState();
}

class _UserFavouritesState extends State<UserFavourites> {

  List<singleProductModel.Data> favouriteList = [];
  List favouriteListFavs = [];
  Color? defaultColor;

  @override
  void initState() {
    checkCheck();
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    // currency = currencySymbol!;
    
    setState(() {});
  }

  checkCheck() async {
    favouriteList.clear();
    var favourites = await StoreBountyInit.getAllUserFavourites();
    for (var i = 0; i < favourites.length; i++) {
        var value = singleProductModel.Data.fromMap(favourites[i]);
        favouriteList.add(value); 
    }
    
    List<dynamic> ids = favourites.map((object) => object['id']).toList();
    favouriteListFavs.addAll(ids);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: TabAppBar(
          title: 'Favorites',
          leftOnClick: () {},
        ),
        body: favouriteList.length < 1 ? 
          Container(child: EmptyFavs(defaultColor: defaultColor ?? Color(0xff000000),),)
        : Container(
          child: widget.cardStyle == "grid"
              ? gridCard(context)
              : fullCard(context),
        ));
  }

  Widget gridCard(BuildContext context) {
    return MediaQuery.removePadding(
      context: context,
      removeTop: true,
      child: GridView.builder(
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 2,
            childAspectRatio: MediaQuery.of(context).size.width /
                (MediaQuery.of(context).size.height / 1.5),
          ),
          itemCount: 4,
          itemBuilder: (BuildContext context, int index) {
            return GridCard(
              title: 'fsdsf sdfsdf sd',
              amount: '5000',
              defaultColor: defaultColor,
            );
          }),
    );
  }

  Widget fullCard(BuildContext context) {
    return MediaQuery.removePadding(
      context: context,
      removeTop: true,
      child: ListView.builder(
          shrinkWrap: true,
          itemCount: favouriteList.length,
          itemBuilder: (BuildContext context, int index) {
            final data = favouriteList[index];
            return Padding(
                padding: EdgeInsets.symmetric(horizontal: 20, vertical: 10),
                child: FullCard(
                  title: '${data.title}',
                  amount: '${StoreBountyAccount.calculatePriceSingle(data)}',
                  defaultColor: defaultColor ?? Color(0xff000000),
                  description: '${data.description}',
                  isFavourite: favouriteListFavs.contains(data.id),
                  removeFavFunc: ()async{
                    var jsonString = jsonEncode(data.toMap());
                    var jsonValue = jsonDecode(jsonString);
                    await StoreBountyInit.addItemsToFavourites(item: jsonValue);
                    checkCheck();
                  },
                ));
          }),
    );
  }
}

==> storebounty_account-0.0.5.tar.gz: lib/favourites/favourites.dart <==
import 'dart:convert';

import 'package:flutter/material.dart';
import 'package:flutter/src/widgets/framework.dart';
import 'package:flutter/src/widgets/placeholder.dart';
import 'package:storebounty_account/common/tabbar.dart';
import 'package:storebounty_account/model/singleproductmodel.dart'
    as singleProductModel;
import 'package:storebounty_account/storebounty_account.dart';
import 'package:storebounty_account/widget/emptyfavs.dart';
import 'package:storebounty_account/widget/favcards/fullcard.dart';
import 'package:storebounty_account/widget/favcards/gridcard.dart';
import 'package:storebounty_init/storebountyinit.dart';

class UserFavourites extends StatefulWidget {
  final String? cardStyle;
  const UserFavourites({super.key, this.cardStyle = "grid"});

  @override
  State<UserFavourites> createState() => _UserFavouritesState();
}

class _UserFavouritesState extends State<UserFavourites> {
  List<singleProductModel.Data> favouriteList = [];
  List favouriteListFavs = [];
  Color? defaultColor;

  @override
  void initState() {
    checkCheck();
    getColor();
    super.initState();
  }

  getColor() async {
    var colorString = await StoreBountyInit.getStoreColor() ?? "#000000";
    defaultColor = Color(int.parse("0xff" + colorString.substring(1)));
    var currencySymbol = await StoreBountyInit.getCurrencySymbol();
    // currency = currencySymbol!;

    setState(() {});
  }

  checkCheck() async {
    favouriteList.clear();
    var favourites = await StoreBountyInit.getAllUserFavourites();
    for (var i = 0; i < favourites.length; i++) {
      var value = singleProductModel.Data.fromMap(favourites[i]);
      favouriteList.add(value);
    }

    List<dynamic> ids = favourites.map((object) => object['id']).toList();
    favouriteListFavs.addAll(ids);
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: TabAppBar(
          title: 'Favorites',
          leftOnClick: () {},
        ),
        body: favouriteList.length < 1
            ? Container(
                child: EmptyFavs(
                  defaultColor: defaultColor ?? Color(0xff000000),
                ),
              )
            : Container(
                child: widget.cardStyle == "grid"
                    ? gridCard(context)
                    : fullCard(context),
              ));
  }

  Widget gridCard(BuildContext context) {
    return MediaQuery.removePadding(
      context: context,
      removeTop: true,
      child: GridView.builder(
          shrinkWrap: true,
          physics: const NeverScrollableScrollPhysics(),
          gridDelegate: SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 2,
            childAspectRatio: MediaQuery.of(context).size.width /
                (MediaQuery.of(context).size.height / 1.5),
          ),
          itemCount: 4,
          itemBuilder: (BuildContext context, int index) {
            return GridCard(
              title: 'fsdsf sdfsdf sd',
              amount: '5000',
              defaultColor: defaultColor,
            );
          }),
    );
  }

  Widget fullCard(BuildContext context) {
    return MediaQuery.removePadding(
      context: context,
      removeTop: true,
      child: ListView.builder(
          shrinkWrap: true,
          itemCount: favouriteList.length,
          itemBuilder: (BuildContext context, int index) {
            final data = favouriteList[index];
            return Padding(
                padding: EdgeInsets.symmetric(horizontal: 20, vertical: 10),
                child: FullCard(
                  title: '${data.title}',
                  amount: '${StoreBountyAccount.calculatePriceSingle(data)}',
                  defaultColor: defaultColor ?? Color(0xff000000),
                  description: '${data.description}',
                  isFavourite: favouriteListFavs.contains(data.id),
                  removeFavFunc: () async {
                    var jsonString = jsonEncode(data.toMap());
                    var jsonValue = jsonDecode(jsonString);
                    await StoreBountyInit.addItemsToFavourites(item: jsonValue);
                    checkCheck();
                  },
                ));
          }),
    );
  }
}
